@@ -1,10 +1,10 @@
 use actix_http::HttpService;
 use actix_server::Server;
 use actix_service::map_config;
-use actix_web::{dev::AppConfig, get, App};
+use actix_web::{dev::AppConfig, get, App, Responder};
 
 #[get("/")]
-async fn index() -> &'static str {
+async fn index() -> impl Responder {
     "Hello, world. From Actix Web!"
 }
 
