@@ -775,23 +775,23 @@ where
         let cfg = self.cfg.clone();
 
         Box::pin(async move {
-            let expect = expect
-                .await
-                .map_err(|e| error!("Init http expect service error: {:?}", e))?;
+            let expect = expect.await.map_err(|err| {
+                tracing::error!("Initialization of HTTP expect service error: {err:?}");
+            })?;
 
             let upgrade = match upgrade {
                 Some(upgrade) => {
-                    let upgrade = upgrade
-                        .await
-                        .map_err(|e| error!("Init http upgrade service error: {:?}", e))?;
+                    let upgrade = upgrade.await.map_err(|err| {
+                        tracing::error!("Initialization of HTTP upgrade service error: {err:?}");
+                    })?;
                     Some(upgrade)
                 }
                 None => None,
             };
 
-            let service = service
-                .await
-                .map_err(|e| error!("Init http service error: {:?}", e))?;
+            let service = service.await.map_err(|err| {
+                tracing::error!("Initialization of HTTP service error: {err:?}");
+            })?;
 
             Ok(HttpServiceHandler::new(
                 cfg,
